@@ -18,22 +18,24 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "dhtpeersource.h"
+#include "announcetask.h"
+#include "dht.h"
 #include <QHostAddress>
-#include <util/log.h>
-#include <util/functions.h>
+#include <interfaces/torrentinterface.h>
 #include <torrent/globals.h>
 #include <torrent/server.h>
-#include <interfaces/torrentinterface.h>
-#include "dht.h"
-#include "announcetask.h"
+#include <util/functions.h>
+#include <util/log.h>
 
 using namespace bt;
 
 namespace dht
 {
-
-DHTPeerSource::DHTPeerSource(DHTBase & dh_table, const bt::SHA1Hash & info_hash, const QString & torrent_name)
-    : dh_table(dh_table), curr_task(0), info_hash(info_hash), torrent_name(torrent_name)
+DHTPeerSource::DHTPeerSource(DHTBase &dh_table, const bt::SHA1Hash &info_hash, const QString &torrent_name)
+    : dh_table(dh_table)
+    , curr_task(0)
+    , info_hash(info_hash)
+    , torrent_name(torrent_name)
 {
     connect(&timer, &QTimer::timeout, this, &DHTPeerSource::onTimeout);
     connect(&dh_table, &DHTBase::started, this, &DHTPeerSource::manualUpdate);
@@ -43,7 +45,6 @@ DHTPeerSource::DHTPeerSource(DHTBase & dh_table, const bt::SHA1Hash & info_hash,
     request_interval = 5 * 60 * 1000;
 }
 
-
 DHTPeerSource::~DHTPeerSource()
 {
     if (curr_task)
@@ -63,7 +64,7 @@ void DHTPeerSource::dhtStopped()
     curr_task = 0;
 }
 
-void DHTPeerSource::stop(bt::WaitJob*)
+void DHTPeerSource::stop(bt::WaitJob *)
 {
     started = false;
     if (curr_task) {
@@ -78,7 +79,6 @@ void DHTPeerSource::manualUpdate()
         doRequest();
 }
 
-
 bool DHTPeerSource::doRequest()
 {
     if (!dh_table.isRunning())
@@ -90,7 +90,7 @@ bool DHTPeerSource::doRequest()
     Uint16 port = ServerInterface::getPort();
     curr_task = dh_table.announce(info_hash, port);
     if (curr_task) {
-        for (const bt::DHTNode & n : qAsConst(nodes))
+        for (const bt::DHTNode &n : qAsConst(nodes))
             curr_task->addDHTNode(n.ip, n.port);
 
         connect(curr_task, &AnnounceTask::dataReady, this, &DHTPeerSource::onDataReady);
@@ -101,7 +101,7 @@ bool DHTPeerSource::doRequest()
     return false;
 }
 
-void DHTPeerSource::onFinished(Task* t)
+void DHTPeerSource::onFinished(Task *t)
 {
     if (curr_task == t) {
         onDataReady(curr_task);
@@ -110,13 +110,13 @@ void DHTPeerSource::onFinished(Task* t)
     }
 }
 
-void DHTPeerSource::onDataReady(Task* t)
+void DHTPeerSource::onDataReady(Task *t)
 {
     if (curr_task == t) {
         Uint32 cnt = 0;
         DBItem item;
         while (curr_task->takeItem(item)) {
-            const net::Address & addr = item.getAddress();
+            const net::Address &addr = item.getAddress();
             /*  Out(SYS_DHT|LOG_NOTICE) <<
                         QString("DHT: Got potential peer %1 for torrent %2")
                         .arg(addr.toString()).arg(tor->getStats().torrent_name) << endl;*/
@@ -125,9 +125,7 @@ void DHTPeerSource::onDataReady(Task* t)
         }
 
         if (cnt) {
-            Out(SYS_DHT | LOG_NOTICE) <<
-                                      QString("DHT: Got %1 potential peers for torrent %2")
-                                      .arg(cnt).arg(torrent_name) << endl;
+            Out(SYS_DHT | LOG_NOTICE) << QString("DHT: Got %1 potential peers for torrent %2").arg(cnt).arg(torrent_name) << endl;
             peersReady(this);
         }
     }
@@ -139,7 +137,7 @@ void DHTPeerSource::onTimeout()
         doRequest();
 }
 
-void DHTPeerSource::addDHTNode(const bt::DHTNode& node)
+void DHTPeerSource::addDHTNode(const bt::DHTNode &node)
 {
     nodes.append(node);
 }
@@ -150,4 +148,3 @@ void DHTPeerSource::setRequestInterval(Uint32 interval)
 }
 
 }
-
