@@ -23,37 +23,40 @@
 #include <QTextStream>
 #include <klocalizedstring.h>
 
-#include <torrent/torrent.h>
-#include <peer/peermanager.h>
-#include <peer/peer.h>
-#include <diskio/chunkmanager.h>
-#include <diskio/piecedata.h>
-#include <util/file.h>
-#include <util/log.h>
-#include <util/error.h>
-#include <util/sha1hash.h>
-#include <util/array.h>
 #include "chunkdownload.h"
-#include <download/piece.h>
-#include <peer/peerdownloader.h>
-#include <peer/badpeerslist.h>
-#include <util/functions.h>
-#include <interfaces/monitorinterface.h>
-#include <peer/accessmanager.h>
-#include <peer/chunkcounter.h>
 #include "chunkselector.h"
 #include "version.h"
 #include "webseed.h"
-
-
+#include <diskio/chunkmanager.h>
+#include <diskio/piecedata.h>
+#include <download/piece.h>
+#include <interfaces/monitorinterface.h>
+#include <peer/accessmanager.h>
+#include <peer/badpeerslist.h>
+#include <peer/chunkcounter.h>
+#include <peer/peer.h>
+#include <peer/peerdownloader.h>
+#include <peer/peermanager.h>
+#include <torrent/torrent.h>
+#include <util/array.h>
+#include <util/error.h>
+#include <util/file.h>
+#include <util/functions.h>
+#include <util/log.h>
+#include <util/sha1hash.h>
 
 namespace bt
 {
-
 bool Downloader::use_webseeds = true;
 
-Downloader::Downloader(Torrent & tor, PeerManager & pman, ChunkManager & cman)
-    : tor(tor), pman(pman), cman(cman), bytes_downloaded(0), tmon(0), chunk_selector(0), webseed_endgame_mode(false)
+Downloader::Downloader(Torrent &tor, PeerManager &pman, ChunkManager &cman)
+    : tor(tor)
+    , pman(pman)
+    , cman(cman)
+    , bytes_downloaded(0)
+    , tmon(0)
+    , chunk_selector(0)
+    , webseed_endgame_mode(false)
 {
     webseeds_on = use_webseeds;
     pman.setPieceHandler(this);
@@ -68,10 +71,10 @@ Downloader::Downloader(Torrent & tor, PeerManager & pman, ChunkManager & cman)
     current_chunks.setAutoDelete(true);
 
     active_webseed_downloads = 0;
-    const QList<QUrl> & urls = tor.getWebSeeds();
+    const QList<QUrl> &urls = tor.getWebSeeds();
     for (const QUrl &u : urls) {
         if (u.scheme() == QLatin1String("http")) {
-            WebSeed* ws = new WebSeed(u, false, tor, cman);
+            WebSeed *ws = new WebSeed(u, false, tor, cman);
             webseeds.append(ws);
             connect(ws, &WebSeed::chunkReady, this, &Downloader::onChunkReady);
             connect(ws, &WebSeed::chunkDownloadStarted, this, &Downloader::chunkDownloadStarted);
@@ -92,14 +95,13 @@ Downloader::Downloader(Torrent & tor, PeerManager & pman, ChunkManager & cman)
     }
 }
 
-
 Downloader::~Downloader()
 {
     delete chunk_selector;
     qDeleteAll(webseeds);
 }
 
-void Downloader::setChunkSelector(ChunkSelectorInterface* csel)
+void Downloader::setChunkSelector(ChunkSelectorInterface *csel)
 {
     delete chunk_selector;
 
@@ -111,17 +113,15 @@ void Downloader::setChunkSelector(ChunkSelectorInterface* csel)
     chunk_selector->init(&cman, this, &pman);
 }
 
-
-void Downloader::pieceReceived(const Piece & p)
+void Downloader::pieceReceived(const Piece &p)
 {
     if (cman.completed())
         return;
 
-    ChunkDownload* cd = current_chunks.find(p.getIndex());
+    ChunkDownload *cd = current_chunks.find(p.getIndex());
     if (!cd) {
         unnecessary_data += p.getLength();
-        Out(SYS_DIO | LOG_DEBUG) <<
-                                 "Unnecessary piece, total unnecessary data : " << BytesToString(unnecessary_data) << endl;
+        Out(SYS_DIO | LOG_DEBUG) << "Unnecessary piece, total unnecessary data : " << BytesToString(unnecessary_data) << endl;
         return;
     }
 
@@ -142,7 +142,7 @@ void Downloader::pieceReceived(const Piece & p)
             current_chunks.erase(p.getIndex());
         } else {
             current_chunks.erase(p.getIndex());
-            for (WebSeed* ws : qAsConst(webseeds)) {
+            for (WebSeed *ws : qAsConst(webseeds)) {
                 if (ws->inCurrentRange(p.getIndex()))
                     ws->chunkDownloaded(p.getIndex());
             }
@@ -154,8 +154,7 @@ void Downloader::pieceReceived(const Piece & p)
 
     if (!ok) {
         unnecessary_data += p.getLength();
-        Out(SYS_DIO | LOG_DEBUG) <<
-                                 "Unnecessary piece, total unnecessary data : " << BytesToString(unnecessary_data) << endl;
+        Out(SYS_DIO | LOG_DEBUG) << "Unnecessary piece, total unnecessary data : " << BytesToString(unnecessary_data) << endl;
     }
 }
 
@@ -175,28 +174,27 @@ void Downloader::update()
     normalUpdate();
 
     // now see if there aren't any timed out pieces
-    for (PieceDownloader* pd : qAsConst(piece_downloaders)) {
+    for (PieceDownloader *pd : qAsConst(piece_downloaders)) {
         pd->checkTimeouts();
     }
 
     if (use_webseeds) {
-        for (WebSeed* ws : qAsConst(webseeds)) {
+        for (WebSeed *ws : qAsConst(webseeds)) {
             ws->update();
         }
     }
 
     if (isFinished() && webseeds_on) {
-        for (WebSeed* ws : qAsConst(webseeds)) {
+        for (WebSeed *ws : qAsConst(webseeds)) {
             ws->cancel();
         }
     }
 }
 
-
 void Downloader::normalUpdate()
 {
     for (CurChunkItr j = current_chunks.begin(); j != current_chunks.end(); ++j) {
-        ChunkDownload* cd = j->second;
+        ChunkDownload *cd = j->second;
         if (cd->isIdle()) {
             continue;
         } else if (cd->isChoked()) {
@@ -206,7 +204,7 @@ void Downloader::normalUpdate()
         }
     }
 
-    for (PieceDownloader* pd : qAsConst(piece_downloaders)) {
+    for (PieceDownloader *pd : qAsConst(piece_downloaders)) {
         if (!pd->isChoked()) {
             while (pd->canDownloadChunk()) {
                 if (!downloadFrom(pd))
@@ -217,7 +215,7 @@ void Downloader::normalUpdate()
     }
 
     if (use_webseeds) {
-        for (WebSeed* ws : qAsConst(webseeds)) {
+        for (WebSeed *ws : qAsConst(webseeds)) {
             if (!ws->busy() && ws->isEnabled() && ws->failedAttempts() < 3) {
                 downloadFrom(ws);
             }
@@ -225,7 +223,7 @@ void Downloader::normalUpdate()
     } else if (webseeds_on != use_webseeds) {
         // reset all webseeds, webseeds have been disabled
         webseeds_on = use_webseeds;
-        for (WebSeed* ws : qAsConst(webseeds)) {
+        for (WebSeed *ws : qAsConst(webseeds)) {
             if (ws->busy() && ws->isEnabled()) {
                 ws->cancel();
             }
@@ -233,14 +231,13 @@ void Downloader::normalUpdate()
     }
 }
 
-
-ChunkDownload* Downloader::selectCD(PieceDownloader* pd, Uint32 n)
+ChunkDownload *Downloader::selectCD(PieceDownloader *pd, Uint32 n)
 {
-    ChunkDownload* sel = 0;
+    ChunkDownload *sel = 0;
     Uint32 sel_left = 0xFFFFFFFF;
 
     for (CurChunkItr j = current_chunks.begin(); j != current_chunks.end(); ++j) {
-        ChunkDownload* cd = j->second;
+        ChunkDownload *cd = j->second;
         if (pd->isChoked() || !pd->hasChunk(cd->getChunk()->getIndex()))
             continue;
 
@@ -255,10 +252,9 @@ ChunkDownload* Downloader::selectCD(PieceDownloader* pd, Uint32 n)
     return sel;
 }
 
-
-bool Downloader::findDownloadForPD(PieceDownloader* pd)
+bool Downloader::findDownloadForPD(PieceDownloader *pd)
 {
-    ChunkDownload* sel = 0;
+    ChunkDownload *sel = 0;
 
     // See if there are ChunkDownload's which need a PieceDownloader
     sel = selectCD(pd, 0);
@@ -269,11 +265,11 @@ bool Downloader::findDownloadForPD(PieceDownloader* pd)
     return false;
 }
 
-ChunkDownload* Downloader::selectWorst(PieceDownloader* pd)
+ChunkDownload *Downloader::selectWorst(PieceDownloader *pd)
 {
-    ChunkDownload* cdmin = NULL;
+    ChunkDownload *cdmin = NULL;
     for (CurChunkItr j = current_chunks.begin(); j != current_chunks.end(); ++j) {
-        ChunkDownload* cd = j->second;
+        ChunkDownload *cd = j->second;
         if (!pd->hasChunk(cd->getChunk()->getIndex()) || cd->containsPeer(pd))
             continue;
 
@@ -288,7 +284,7 @@ ChunkDownload* Downloader::selectWorst(PieceDownloader* pd)
     return cdmin;
 }
 
-bool Downloader::downloadFrom(PieceDownloader* pd)
+bool Downloader::downloadFrom(PieceDownloader *pd)
 {
     // first see if we can use an existing dowload
     if (findDownloadForPD(pd))
@@ -296,11 +292,11 @@ bool Downloader::downloadFrom(PieceDownloader* pd)
 
     Uint32 chunk = 0;
     if (chunk_selector->select(pd, chunk)) {
-        Chunk* c = cman.getChunk(chunk);
+        Chunk *c = cman.getChunk(chunk);
         if (current_chunks.contains(chunk)) {
             return current_chunks.find(chunk)->assign(pd);
         } else {
-            ChunkDownload* cd = new ChunkDownload(c);
+            ChunkDownload *cd = new ChunkDownload(c);
             current_chunks.insert(chunk, cd);
             cd->assign(pd);
             if (tmon)
@@ -319,7 +315,7 @@ bool Downloader::downloadFrom(PieceDownloader* pd)
     return false;
 }
 
-void Downloader::downloadFrom(WebSeed* ws)
+void Downloader::downloadFrom(WebSeed *ws)
 {
     Uint32 first = 0;
     Uint32 last = 0;
@@ -334,7 +330,6 @@ void Downloader::downloadFrom(WebSeed* ws)
     }
 }
 
-
 bool Downloader::downloading(Uint32 chunk) const
 {
     return current_chunks.find(chunk) != 0;
@@ -345,7 +340,7 @@ bool Downloader::canDownloadFromWebSeed(Uint32 chunk) const
     if (webseed_endgame_mode)
         return true;
 
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         if (ws->busy() && ws->inCurrentRange(chunk))
             return false;
     }
@@ -355,37 +350,37 @@ bool Downloader::canDownloadFromWebSeed(Uint32 chunk) const
 
 Uint32 Downloader::numDownloadersForChunk(Uint32 chunk) const
 {
-    const ChunkDownload* cd = current_chunks.find(chunk);
+    const ChunkDownload *cd = current_chunks.find(chunk);
     if (!cd)
         return 0;
 
     return cd->getNumDownloaders();
 }
 
-void Downloader::addPieceDownloader(PieceDownloader* peer)
+void Downloader::addPieceDownloader(PieceDownloader *peer)
 {
     piece_downloaders.append(peer);
 }
 
-void Downloader::removePieceDownloader(PieceDownloader* peer)
+void Downloader::removePieceDownloader(PieceDownloader *peer)
 {
     for (CurChunkItr i = current_chunks.begin(); i != current_chunks.end(); ++i) {
-        ChunkDownload* cd = i->second;
+        ChunkDownload *cd = i->second;
         cd->killed(peer);
     }
     piece_downloaders.removeAll(peer);
 }
 
-bool Downloader::finished(ChunkDownload* cd)
+bool Downloader::finished(ChunkDownload *cd)
 {
-    Chunk* c = cd->getChunk();
+    Chunk *c = cd->getChunk();
     // verify the data
     SHA1Hash h = cd->getHash();
 
     if (tor.verifyHash(h, c->getIndex())) {
         // hash ok so save it
         try {
-            for (WebSeed* ws : qAsConst(webseeds)) {
+            for (WebSeed *ws : qAsConst(webseeds)) {
                 // tell all webseeds a chunk is downloaded
                 if (ws->inCurrentRange(c->getIndex()))
                     ws->chunkDownloaded(c->getIndex());
@@ -395,13 +390,13 @@ bool Downloader::finished(ChunkDownload* cd)
             Out(SYS_GEN | LOG_IMPORTANT) << "Chunk " << c->getIndex() << " downloaded " << endl;
             pman.sendHave(c->getIndex());
             Q_EMIT chunkDownloaded(c->getIndex());
-        } catch (Error & e) {
+        } catch (Error &e) {
             Out(SYS_DIO | LOG_IMPORTANT) << "Error " << e.toString() << endl;
             Q_EMIT ioError(e.toString());
             return false;
         }
     } else {
-        Out(SYS_GEN | LOG_IMPORTANT) << "Hash verification error on chunk "  << c->getIndex() << endl;
+        Out(SYS_GEN | LOG_IMPORTANT) << "Hash verification error on chunk " << c->getIndex() << endl;
         Out(SYS_GEN | LOG_IMPORTANT) << "Is        : " << h << endl;
         Out(SYS_GEN | LOG_IMPORTANT) << "Should be : " << tor.getHash(c->getIndex()) << endl;
 
@@ -411,7 +406,7 @@ bool Downloader::finished(ChunkDownload* cd)
 
         chunk_selector->reinsert(c->getIndex());
 
-        PieceDownloader* only = cd->getOnlyDownloader();
+        PieceDownloader *only = cd->getOnlyDownloader();
         if (only) {
             Peer::Ptr p = pman.findPeer(only);
             if (!p)
@@ -432,7 +427,7 @@ void Downloader::clearDownloads()
     current_chunks.clear();
     piece_downloaders.clear();
 
-    for (WebSeed* ws : qAsConst(webseeds))
+    for (WebSeed *ws : qAsConst(webseeds))
         ws->cancel();
 }
 
@@ -440,13 +435,13 @@ void Downloader::pause()
 {
     if (tmon) {
         for (CurChunkItr i = current_chunks.begin(); i != current_chunks.end(); ++i) {
-            ChunkDownload* cd = i->second;
+            ChunkDownload *cd = i->second;
             tmon->downloadRemoved(cd);
         }
     }
 
     current_chunks.clear();
-    for (WebSeed* ws : qAsConst(webseeds))
+    for (WebSeed *ws : qAsConst(webseeds))
         ws->reset();
 }
 
@@ -454,40 +449,36 @@ Uint32 Downloader::downloadRate() const
 {
     // sum of the download rate of each peer
     Uint32 rate = 0;
-    for (PieceDownloader* pd : qAsConst(piece_downloaders))
+    for (PieceDownloader *pd : qAsConst(piece_downloaders))
         if (pd)
             rate += pd->getDownloadRate();
 
-
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         rate += ws->getDownloadRate();
     }
 
     return rate;
 }
 
-void Downloader::setMonitor(MonitorInterface* tmo)
+void Downloader::setMonitor(MonitorInterface *tmo)
 {
     tmon = tmo;
     if (!tmon)
         return;
 
     for (CurChunkItr i = current_chunks.begin(); i != current_chunks.end(); ++i) {
-        ChunkDownload* cd = i->second;
+        ChunkDownload *cd = i->second;
         tmon->downloadStarted(cd);
     }
 
-    for (WebSeed* ws : qAsConst(webseeds)) {
-        WebSeedChunkDownload* cd = ws->currentChunkDownload();
+    for (WebSeed *ws : qAsConst(webseeds)) {
+        WebSeedChunkDownload *cd = ws->currentChunkDownload();
         if (cd)
             tmon->downloadStarted(cd);
     }
-
 }
 
-
-
-void Downloader::saveDownloads(const QString & file)
+void Downloader::saveDownloads(const QString &file)
 {
     File fptr;
     if (!fptr.open(file, "wb"))
@@ -512,12 +503,12 @@ void Downloader::saveDownloads(const QString & file)
 
     Out(SYS_GEN | LOG_DEBUG) << "Saving " << current_chunks.count() << " chunk downloads" << endl;
     for (CurChunkItr i = current_chunks.begin(); i != current_chunks.end(); ++i) {
-        ChunkDownload* cd = i->second;
+        ChunkDownload *cd = i->second;
         cd->save(fptr);
     }
 }
 
-void Downloader::loadDownloads(const QString & file)
+void Downloader::loadDownloads(const QString &file)
 {
     // don't load stuff if download is finished
     if (cman.completed())
@@ -538,7 +529,7 @@ void Downloader::loadDownloads(const QString & file)
         return;
     }
 
-    Out(SYS_GEN | LOG_DEBUG) << "Loading " << chdr.num_chunks  << " active chunk downloads" << endl;
+    Out(SYS_GEN | LOG_DEBUG) << "Loading " << chdr.num_chunks << " active chunk downloads" << endl;
     for (Uint32 i = 0; i < chdr.num_chunks; i++) {
         ChunkDownloadHeader hdr;
         // first read header
@@ -549,13 +540,13 @@ void Downloader::loadDownloads(const QString & file)
             return;
         }
 
-        Chunk* c = cman.getChunk(hdr.index);
+        Chunk *c = cman.getChunk(hdr.index);
         if (!c || current_chunks.contains(hdr.index)) {
             Out(SYS_GEN | LOG_DEBUG) << "Illegal chunk " << hdr.index << endl;
             return;
         }
 
-        ChunkDownload* cd = new ChunkDownload(c);
+        ChunkDownload *cd = new ChunkDownload(c);
         bool ret = false;
         try {
             ret = cd->load(fptr, hdr);
@@ -578,7 +569,7 @@ void Downloader::loadDownloads(const QString & file)
     curr_chunks_downloaded = 0;
 }
 
-Uint32 Downloader::getDownloadedBytesOfCurrentChunksFile(const QString & file)
+Uint32 Downloader::getDownloadedBytesOfCurrentChunksFile(const QString &file)
 {
     // Load all partial downloads
     File fptr;
@@ -600,7 +591,7 @@ Uint32 Downloader::getDownloadedBytesOfCurrentChunksFile(const QString & file)
         ChunkDownloadHeader hdr;
         fptr.read(&hdr, sizeof(ChunkDownloadHeader));
 
-        Chunk* c = cman.getChunk(hdr.index);
+        Chunk *c = cman.getChunk(hdr.index);
         if (!c)
             return num_bytes;
 
@@ -622,7 +613,7 @@ bool Downloader::isFinished() const
 void Downloader::onExcluded(Uint32 from, Uint32 to)
 {
     for (Uint32 i = from; i <= to; i++) {
-        ChunkDownload* cd = current_chunks.find(i);
+        ChunkDownload *cd = current_chunks.find(i);
         if (!cd)
             continue;
 
@@ -634,7 +625,7 @@ void Downloader::onExcluded(Uint32 from, Uint32 to)
         cman.resetChunk(i); // reset chunk it is not fully downloaded yet
     }
 
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         ws->onExcluded(from, to);
     }
 }
@@ -649,10 +640,10 @@ void Downloader::corrupted(Uint32 chunk)
     chunk_selector->reinsert(chunk);
 }
 
-void Downloader::dataChecked(const bt::BitSet& ok_chunks, Uint32 from, Uint32 to)
+void Downloader::dataChecked(const bt::BitSet &ok_chunks, Uint32 from, Uint32 to)
 {
     for (Uint32 i = from; i < ok_chunks.getNumBits() && i <= to; i++) {
-        ChunkDownload* cd = current_chunks.find(i);
+        ChunkDownload *cd = current_chunks.find(i);
         if (ok_chunks.get(i) && cd) {
             // we have a chunk and we are downloading it so kill it
             cd->releaseAllPDs();
@@ -671,9 +662,9 @@ void Downloader::recalcDownloaded()
     bytes_downloaded = (total - cman.bytesLeft());
 }
 
-void Downloader::onChunkReady(Chunk* c)
+void Downloader::onChunkReady(Chunk *c)
 {
-    WebSeed* ws = webseeds_chunks.find(c->getIndex());
+    WebSeed *ws = webseeds_chunks.find(c->getIndex());
     webseeds_chunks.erase(c->getIndex());
     PieceData::Ptr piece = c->getPiece(0, c->getSize(), true);
     if (piece && c->checkHash(tor.getHash(c->getIndex()))) {
@@ -681,13 +672,13 @@ void Downloader::onChunkReady(Chunk* c)
         try {
             bytes_downloaded += c->getSize();
 
-            for (WebSeed* ws : qAsConst(webseeds)) {
+            for (WebSeed *ws : qAsConst(webseeds)) {
                 // tell all webseeds a chunk is downloaded
                 if (ws->inCurrentRange(c->getIndex()))
                     ws->chunkDownloaded(c->getIndex());
             }
 
-            ChunkDownload* cd = current_chunks.find(c->getIndex());
+            ChunkDownload *cd = current_chunks.find(c->getIndex());
             if (cd) {
                 // A ChunkDownload is ongoing for this chunk so kill it, we have the chunk
                 cd->cancelAll();
@@ -702,12 +693,12 @@ void Downloader::onChunkReady(Chunk* c)
             Out(SYS_GEN | LOG_IMPORTANT) << "Chunk " << c->getIndex() << " downloaded via webseed ! " << endl;
             // tell everybody we have the Chunk
             pman.sendHave(c->getIndex());
-        } catch (Error & e) {
+        } catch (Error &e) {
             Out(SYS_DIO | LOG_IMPORTANT) << "Error " << e.toString() << endl;
             Q_EMIT ioError(e.toString());
         }
     } else {
-        Out(SYS_GEN | LOG_IMPORTANT) << "Hash verification error on chunk "  << c->getIndex() << endl;
+        Out(SYS_GEN | LOG_IMPORTANT) << "Hash verification error on chunk " << c->getIndex() << endl;
         // reset chunk but only when no other peer is downloading it
         if (!current_chunks.find(c->getIndex()))
             cman.resetChunk(c->getIndex());
@@ -717,7 +708,7 @@ void Downloader::onChunkReady(Chunk* c)
     }
 }
 
-void Downloader::chunkDownloadStarted(WebSeedChunkDownload* cd, Uint32 chunk)
+void Downloader::chunkDownloadStarted(WebSeedChunkDownload *cd, Uint32 chunk)
 {
     webseeds_chunks.insert(chunk, cd->ws);
     active_webseed_downloads++;
@@ -725,7 +716,7 @@ void Downloader::chunkDownloadStarted(WebSeedChunkDownload* cd, Uint32 chunk)
         tmon->downloadStarted(cd);
 }
 
-void Downloader::chunkDownloadFinished(WebSeedChunkDownload* cd, Uint32 chunk)
+void Downloader::chunkDownloadFinished(WebSeedChunkDownload *cd, Uint32 chunk)
 {
     webseeds_chunks.erase(chunk);
     if (active_webseed_downloads > 0)
@@ -735,15 +726,15 @@ void Downloader::chunkDownloadFinished(WebSeedChunkDownload* cd, Uint32 chunk)
         tmon->downloadRemoved(cd);
 }
 
-WebSeed* Downloader::addWebSeed(const QUrl &url)
+WebSeed *Downloader::addWebSeed(const QUrl &url)
 {
     // Check for dupes
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         if (ws->getUrl() == url)
             return 0;
     }
 
-    WebSeed* ws = new WebSeed(url, true, tor, cman);
+    WebSeed *ws = new WebSeed(url, true, tor, cman);
     webseeds.append(ws);
     connect(ws, &WebSeed::chunkReady, this, &Downloader::onChunkReady);
     connect(ws, &WebSeed::chunkDownloadStarted, this, &Downloader::chunkDownloadStarted);
@@ -753,7 +744,7 @@ WebSeed* Downloader::addWebSeed(const QUrl &url)
 
 bool Downloader::removeWebSeed(const QUrl &url)
 {
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         if (ws->getUrl() == url && ws->isUserCreated()) {
             PtrMap<Uint32, WebSeed>::iterator i = webseeds_chunks.begin();
             while (i != webseeds_chunks.end()) {
@@ -776,7 +767,7 @@ void Downloader::removeAllWebSeeds()
     webseeds_chunks.clear();
 }
 
-void Downloader::saveWebSeeds(const QString & file)
+void Downloader::saveWebSeeds(const QString &file)
 {
     QFile fptr(file);
     if (!fptr.open(QIODevice::WriteOnly)) {
@@ -785,18 +776,18 @@ void Downloader::saveWebSeeds(const QString & file)
     }
 
     QTextStream out(&fptr);
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         if (ws->isUserCreated())
             out << ws->getUrl().toDisplayString() << Qt::endl;
     }
     out << "====disabled====" << Qt::endl;
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         if (!ws->isEnabled())
             out << ws->getUrl().toDisplayString() << Qt::endl;
     }
 }
 
-void Downloader::loadWebSeeds(const QString & file)
+void Downloader::loadWebSeeds(const QString &file)
 {
     QFile fptr(file);
     if (!fptr.open(QIODevice::ReadOnly)) {
@@ -818,14 +809,14 @@ void Downloader::loadWebSeeds(const QString & file)
             continue;
 
         if (disabled_list_found) {
-            for (WebSeed* ws : qAsConst(webseeds)) {
+            for (WebSeed *ws : qAsConst(webseeds)) {
                 if (ws->getUrl() == url) {
                     ws->setEnabled(false);
                     break;
                 }
             }
         } else {
-            WebSeed* ws = new WebSeed(url, true, tor, cman);
+            WebSeed *ws = new WebSeed(url, true, tor, cman);
             webseeds.append(ws);
             connect(ws, &WebSeed::chunkReady, this, &Downloader::onChunkReady);
             connect(ws, &WebSeed::chunkDownloadStarted, this, &Downloader::chunkDownloadStarted);
@@ -836,17 +827,17 @@ void Downloader::loadWebSeeds(const QString & file)
 
 void Downloader::setGroupIDs(Uint32 up, Uint32 down)
 {
-    for (WebSeed* ws : qAsConst(webseeds)) {
+    for (WebSeed *ws : qAsConst(webseeds)) {
         ws->setGroupIDs(up, down);
     }
 }
 
-ChunkDownload* Downloader::download(Uint32 chunk)
+ChunkDownload *Downloader::download(Uint32 chunk)
 {
     return current_chunks.find(chunk);
 }
 
-const bt::ChunkDownload* Downloader::download(Uint32 chunk) const
+const bt::ChunkDownload *Downloader::download(Uint32 chunk) const
 {
     return current_chunks.find(chunk);
 }
