@@ -18,44 +18,40 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "uploader.h"
-#include <util/log.h>
-#include <peer/peer.h>
 #include <diskio/chunkmanager.h>
 #include <download/request.h>
-#include <peer/peeruploader.h>
+#include <peer/peer.h>
 #include <peer/peermanager.h>
-
+#include <peer/peeruploader.h>
+#include <util/log.h>
 
 namespace bt
 {
-
-Uploader::Uploader(ChunkManager & cman, PeerManager & pman)
-    : cman(cman), pman(pman), uploaded(0)
-{}
-
+Uploader::Uploader(ChunkManager &cman, PeerManager &pman)
+    : cman(cman)
+    , pman(pman)
+    , uploaded(0)
+{
+}
 
 Uploader::~Uploader()
 {
 }
 
-
 void Uploader::visit(const bt::Peer::Ptr p)
 {
-    PeerUploader* pu = p->getPeerUploader();
+    PeerUploader *pu = p->getPeerUploader();
     uploaded += pu->handleRequests(cman);
 }
 
-
 void Uploader::update()
 {
     pman.visit(*this);
 }
 
-
 Uint32 Uploader::uploadRate() const
 {
     return pman.uploadRate();
 }
 
-
 }
