@@ -19,25 +19,27 @@
  ***************************************************************************/
 
 #include "circularbuffer.h"
+#include "log.h"
 #include <string.h>
 #include <util/log.h>
-#include "log.h"
-
 
 namespace bt
 {
-
-CircularBuffer::CircularBuffer(Uint32 cap) : data(0), buf_capacity(cap), start(0), buf_size(0)
+CircularBuffer::CircularBuffer(Uint32 cap)
+    : data(0)
+    , buf_capacity(cap)
+    , start(0)
+    , buf_size(0)
 {
     data = new Uint8[cap];
 }
 
 CircularBuffer::~CircularBuffer()
 {
-    delete [] data;
+    delete[] data;
 }
 
-bt::Uint32 CircularBuffer::read(bt::Uint8* ptr, bt::Uint32 max_len)
+bt::Uint32 CircularBuffer::read(bt::Uint8 *ptr, bt::Uint32 max_len)
 {
     if (empty())
         return 0;
@@ -56,12 +58,12 @@ bt::Uint32 CircularBuffer::read(bt::Uint8* ptr, bt::Uint32 max_len)
 
     start = (start + to_read) % buf_capacity;
     buf_size -= to_read;
-    //Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::read 1 " << size() << " " << capacity() << endl;
-    //Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::read 2 " << start << " " << to_read << endl;
+    // Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::read 1 " << size() << " " << capacity() << endl;
+    // Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::read 2 " << start << " " << to_read << endl;
     return to_read;
 }
 
-bt::Uint32 CircularBuffer::write(const bt::Uint8* ptr, bt::Uint32 len)
+bt::Uint32 CircularBuffer::write(const bt::Uint8 *ptr, bt::Uint32 len)
 {
     if (full())
         return 0;
@@ -79,8 +81,8 @@ bt::Uint32 CircularBuffer::write(const bt::Uint8* ptr, bt::Uint32 len)
     }
 
     buf_size += to_write;
-    //Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::write 1 " << size() << " " << capacity() << endl;
-    //Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::write 2 " << start << " " << to_write << endl;
+    // Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::write 1 " << size() << " " << capacity() << endl;
+    // Out(SYS_GEN|LOG_DEBUG) << "CircularBuffer::write 2 " << start << " " << to_write << endl;
     return to_write;
 }
 
@@ -97,8 +99,7 @@ CircularBuffer::Range CircularBuffer::secondRange()
     if (start + buf_size > buf_capacity)
         return Range(data, buf_size - (buf_capacity - start));
     else
-        return Range((bt::Uint8*)0, 0);
+        return Range((bt::Uint8 *)0, 0);
 }
 
 }
-
